summaryrefslogtreecommitdiff
path: root/uvim/runtime/macros
diff options
context:
space:
mode:
authorMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-03 22:21:25 +0300
committerMehmet Samet Duman <yongdohyun@projecttick.org>2026-04-04 00:23:03 +0300
commit2eae5db069dc171f74cd863487655f6a88e5384d (patch)
tree2d9d05e09978a2a44acbfbb8d651f240df3ca052 /uvim/runtime/macros
parent473d922faed49241a5d29d9e37dc4819cd512006 (diff)
downloadProject-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.tar.gz
Project-Tick-2eae5db069dc171f74cd863487655f6a88e5384d.zip
NOISSUE rebrand vim to MNV's not Vim
Signed-off-by: Mehmet Samet Duman <yongdohyun@projecttick.org>
Diffstat (limited to 'uvim/runtime/macros')
-rw-r--r--uvim/runtime/macros/README.txt10
-rw-r--r--uvim/runtime/macros/editexisting.mnv (renamed from uvim/runtime/macros/editexisting.vim)0
-rw-r--r--uvim/runtime/macros/hanoi/click.me4
-rw-r--r--uvim/runtime/macros/hanoi/hanoi.mnv (renamed from uvim/runtime/macros/hanoi/hanoi.vim)0
-rw-r--r--uvim/runtime/macros/justify.mnv (renamed from uvim/runtime/macros/justify.vim)0
-rw-r--r--uvim/runtime/macros/less.bat6
-rw-r--r--uvim/runtime/macros/less.mnv (renamed from uvim/runtime/macros/less.vim)16
-rwxr-xr-xuvim/runtime/macros/less.sh4
-rw-r--r--uvim/runtime/macros/life/click.me4
-rw-r--r--uvim/runtime/macros/life/life.mnv (renamed from uvim/runtime/macros/life/life.vim)45
-rw-r--r--uvim/runtime/macros/matchit.mnv (renamed from uvim/runtime/macros/matchit.vim)0
-rw-r--r--uvim/runtime/macros/maze/README.txt6
-rw-r--r--uvim/runtime/macros/maze/maze_5.782
-rw-r--r--uvim/runtime/macros/shellmenu.mnv (renamed from uvim/runtime/macros/shellmenu.vim)0
-rw-r--r--uvim/runtime/macros/swapmous.mnv (renamed from uvim/runtime/macros/swapmous.vim)0
-rw-r--r--uvim/runtime/macros/urm/README.txt12
-rw-r--r--uvim/runtime/macros/urm/urm.mnv (renamed from uvim/runtime/macros/urm/urm.vim)0
17 files changed, 57 insertions, 52 deletions
diff --git a/uvim/runtime/macros/README.txt b/uvim/runtime/macros/README.txt
index 22f9a97442..2a77f09512 100644
--- a/uvim/runtime/macros/README.txt
+++ b/uvim/runtime/macros/README.txt
@@ -1,4 +1,4 @@
-The macros in the maze, hanoi and urm directories can be used to test Vim for
+The macros in the maze, hanoi and urm directories can be used to test MNV for
vi compatibility. They have been written for vi to show its unlimited
possibilities. The life macros can be used for performance comparisons.
@@ -10,19 +10,19 @@ urm Macros that simulate a simple computer: "Universal Register Machine"
The other files contain some handy utilities. They also serve as examples for
-how to use Vi and Vim functionality.
+how to use Vi and MNV functionality.
-less.sh + less.vim make Vim work like less (or more)
+less.sh + less.mnv make MNV work like less (or more)
The following have been moved to an optional package. Add the command to your
-vimrc file to use the package:
+mnvrc file to use the package:
packadd! dvorak " Dvorak keyboard support; adds mappings
packadd! editexisting " when editing a file that is already edited with
- " another Vim instance, go to that Vim instance
+ " another MNV instance, go to that MNV instance
packadd! justify " justifying text.
diff --git a/uvim/runtime/macros/editexisting.vim b/uvim/runtime/macros/editexisting.mnv
index 6e8f74f22f..6e8f74f22f 100644
--- a/uvim/runtime/macros/editexisting.vim
+++ b/uvim/runtime/macros/editexisting.mnv
diff --git a/uvim/runtime/macros/hanoi/click.me b/uvim/runtime/macros/hanoi/click.me
index 24f178bfe3..67b986d4e3 100644
--- a/uvim/runtime/macros/hanoi/click.me
+++ b/uvim/runtime/macros/hanoi/click.me
@@ -1,9 +1,9 @@
-See Vim solve the towers of Hanoi!
+See MNV solve the towers of Hanoi!
Instructions:
- type ":so hanoi.vim<RETURN>" to load the macros
+ type ":so hanoi.mnv<RETURN>" to load the macros
type "g" to start it
and watch it go.
diff --git a/uvim/runtime/macros/hanoi/hanoi.vim b/uvim/runtime/macros/hanoi/hanoi.mnv
index 1d075fa21f..1d075fa21f 100644
--- a/uvim/runtime/macros/hanoi/hanoi.vim
+++ b/uvim/runtime/macros/hanoi/hanoi.mnv
diff --git a/uvim/runtime/macros/justify.vim b/uvim/runtime/macros/justify.mnv
index 011a911401..011a911401 100644
--- a/uvim/runtime/macros/justify.vim
+++ b/uvim/runtime/macros/justify.mnv
diff --git a/uvim/runtime/macros/less.bat b/uvim/runtime/macros/less.bat
index bbe619bc92..8bf1016de8 100644
--- a/uvim/runtime/macros/less.bat
+++ b/uvim/runtime/macros/less.bat
@@ -1,10 +1,10 @@
@echo off
-rem batch file to start Vim with less.vim.
+rem batch file to start MNV with less.mnv.
rem Read stdin if no arguments were given.
rem Written by Ken Takata.
if "%1"=="" (
- vim --cmd "let no_plugin_maps = 1" -c "runtime! macros/less.vim" -
+ mnv --cmd "let no_plugin_maps = 1" -c "runtime! macros/less.mnv" -
) else (
- vim --cmd "let no_plugin_maps = 1" -c "runtime! macros/less.vim" %*
+ mnv --cmd "let no_plugin_maps = 1" -c "runtime! macros/less.mnv" %*
)
diff --git a/uvim/runtime/macros/less.vim b/uvim/runtime/macros/less.mnv
index 03a0e90941..8bed23db5a 100644
--- a/uvim/runtime/macros/less.vim
+++ b/uvim/runtime/macros/less.mnv
@@ -1,7 +1,7 @@
-" Vim script to work like "less"
-" Maintainer: The Vim Project <https://github.com/vim/vim>
+" MNV script to work like "less"
+" Maintainer: The MNV Project <https://github.com/Project-Tick/Project-Tick>
" Last Change: 2024 Feb 15
-" Former Maintainer: Bram Moolenaar <Bram@vim.org>
+" Former Maintainer: Bram Moolenaar <Bram@mnv.org>
" Avoid loading this file twice, allow the user to define his own script.
if exists("loaded_less")
@@ -51,7 +51,7 @@ set hlsearch
set incsearch
nohlsearch
" Don't remember file names and positions
-set viminfo=
+set mnvinfo=
set nows
" Inhibit screen updates while searching
let s:lz = &lz
@@ -66,14 +66,14 @@ endif
" Used after each command: put cursor at end and display position
if &wrap
noremap <SID>L L0:redraw<CR>:file<CR>
- au VimEnter * normal! L0
+ au MNVEnter * normal! L0
else
noremap <SID>L Lg0:redraw<CR>:file<CR>
- au VimEnter * normal! Lg0
+ au MNVEnter * normal! Lg0
endif
" When reading from stdin don't consider the file modified.
-au VimEnter * set nomod
+au MNVEnter * set nomod
" Can't modify the text or write the file.
set nomodifiable readonly
@@ -404,4 +404,4 @@ fun! s:End()
endif
endfun
-" vim: sw=2
+" mnv: sw=2
diff --git a/uvim/runtime/macros/life/click.me b/uvim/runtime/macros/life/click.me
index c2ed4691aa..269a342e53 100644
--- a/uvim/runtime/macros/life/click.me
+++ b/uvim/runtime/macros/life/click.me
@@ -1,9 +1,9 @@
To run the "Conway's game of life" macros:
- 1. Type ":so life.vim". This loads the macros.
+ 1. Type ":so life.mnv". This loads the macros.
2. Type "g" to run the macros.
3. Type CTRL-C to interrupt.
4. Type ":q!" to get out.
-See life.vim for more advanced usage.
+See life.mnv for more advanced usage.
diff --git a/uvim/runtime/macros/life/life.vim b/uvim/runtime/macros/life/life.mnv
index 29832f0227..546bb0f8c2 100644
--- a/uvim/runtime/macros/life/life.vim
+++ b/uvim/runtime/macros/life/life.mnv
@@ -1,10 +1,10 @@
" Macros to play Conway's Game of Life in vi
" Version 1.0m: edges wrap
-" by Eli-the-Bearded Benjamin Elijah Griffin <vim@eli.users.panix.com>
+" by Eli-the-Bearded Benjamin Elijah Griffin <mnv@eli.users.panix.com>
" Sept 1996
" This file may be free distributed so long as these credits remain unchanged.
"
-" Modified by Bram Moolenaar (Bram@vim.org), 1996 Sept 10
+" Modified by Bram Moolenaar (Bram@mnv.org), 1996 Sept 10
" - Made it quite a bit faster, but now needs search patterns in the text
" - Changed the order of mappings to top-down.
" - Made "g" run the whole thing, "C" run one generation.
@@ -31,7 +31,7 @@
"
" To use these macros:
"
-" vi start vi/vim
+" vi start vi/mnv
"
" :so life.mac Source this file
"
@@ -52,19 +52,19 @@
" 'z' to time that many generations.
"
" Time to run 30 generations on my 233 AMD K6 (FreeBSD 3.0):
-" vim 5.4 xterm 51 sec
-" gvim 5.4 Athena 42 sec
-" gvim 5.4 Motif 42 sec
-" gvim 5.4 GTK 50 sec
+" mnv 5.4 xterm 51 sec
+" gmnv 5.4 Athena 42 sec
+" gmnv 5.4 Motif 42 sec
+" gmnv 5.4 GTK 50 sec
" nvi 1.79 xterm 58 sec
" vi 3.7 xterm 2 min 30 sec
" Elvis 2.1 xterm 7 min 50 sec
" Elvis 2.1 X11 6 min 31 sec
"
" Time to run 30 generations on my 850 AMD Duron (FreeBSD 4.2):
-" vim 5.8 xterm 21 sec
-" vim 6.0 xterm 24 sec
-" vim 6.0 Motif 32 sec
+" mnv 5.8 xterm 21 sec
+" mnv 6.0 xterm 24 sec
+" mnv 6.0 Motif 32 sec
" nvi 1.79 xterm 29 sec
" vi 3.7 xterm 32 sec
" elvis 2.1.4 xterm 34 sec
@@ -103,7 +103,7 @@ map z ,^,&,*,&<1,*<2
"
" ----- Initialisation -----
"
-map ,- :s/./-/g
+map ,- :s/./-/g
map ,o oPut 'X's in the left box, then hit 'C' or 'R'
map ,R 03stop
"
@@ -144,7 +144,8 @@ map ,Iaa o=AB =BC =CD =DE =EF =FG =GH =HI =IJ =JK =KL =LM =MN =NO =OP =PQ =QR
map ,Iab o=RS =ST =TU =UV =VW =WX =XY =YZ =Z 
"
" Insert the searched patterns above the board
-map ,IIN G?^top ,Il8,Id8,Il7,Id7,Il6,Id6,Il5,Id5,Il4,Id4,Il3,Id3,Il2,Id2,Il1,Id1,Il0,Id0,Iaa,Iab
+map ,IIN G?^top
+,Il8,Id8,Il7,Id7,Il6,Id6,Il5,Id5,Il4,Id4,Il3,Id3,Il2,Id2,Il1,Id1,Il0,Id0,Iaa,Iab
"
" ----- END of Initialisation -----
"
@@ -160,7 +161,7 @@ map B ,%k>,$
map > 0 LWWWWWWWWWWWWWWWWWW,rj
"
" Refresh board (used by show next)
-map & :%s/^\(-[ A-Z]*-\)\(-[ A-Z]*-\)\(-[.]*-\)$/\2\3\3/
+map & :%s/^\(-[ A-Z]*-\)\(-[ A-Z]*-\)\(-[.]*-\)$/\2\3\3/
"
"
" Work around vi multiple yank/put in a single macro limitation
@@ -206,17 +207,18 @@ map ,3 3y G$p
" line, and then run the edit command. (used by work out square).
" Leaves the cursor on the next character to be processed.
"
-map ( ,s,i,X0i?^#A  0,df.l,Y21h
+map ( ,s,i,X0i?^#A 
+0,df.l,Y21h
"
" Delete 's'paces (deads);
" The number of remaining characters is the number of living neighbours.
-map ,s :.g/ /s///g
+map ,s :.g/ /s///g
"
" Insert current character in the last line
map ,i `ay GP
"
" Replace any uppercase letter with 'X';
-map ,X :.g/[A-Z]/s//X/g
+map ,X :.g/[A-Z]/s//X/g
"
" Delete and execute the rest of the line
map ,d "qd$@q
@@ -234,16 +236,19 @@ map ,m p
map ,n x
"
" Replace a character by its next, A --> B, B --> C, etc.
-map ,a `a,jGi?=,ma 0,dll,j`a21l,ml,nh
+map ,a `a,jGi?=,ma
+0,dll,j`a21l,ml,nh
"
" ----- END of Work out one germ -----
"
" ----- timing macros -----
"
" Get current date (used by time a generation)
-map << :r!date
-map <1 G?^top O<<
-map <2 G?^top k<<
+map << :r!date
+map <1 G?^top
+O<<
+map <2 G?^top
+k<<
"
"
" Turn number on current line into edit command (used by time N generations)
diff --git a/uvim/runtime/macros/matchit.vim b/uvim/runtime/macros/matchit.mnv
index f6f463f40c..f6f463f40c 100644
--- a/uvim/runtime/macros/matchit.vim
+++ b/uvim/runtime/macros/matchit.mnv
diff --git a/uvim/runtime/macros/maze/README.txt b/uvim/runtime/macros/maze/README.txt
index be8e8ef204..6d747f4867 100644
--- a/uvim/runtime/macros/maze/README.txt
+++ b/uvim/runtime/macros/maze/README.txt
@@ -1,9 +1,9 @@
-To run the maze macros with Vim:
+To run the maze macros with MNV:
- vim -u maze_mac maze_5.78
+ mnv -u maze_mac maze_5.78
press "g"
-The "-u maze.mac" loads the maze macros and skips loading your .vimrc, which
+The "-u maze.mac" loads the maze macros and skips loading your .mnvrc, which
may contain settings and mappings that get in the way.
diff --git a/uvim/runtime/macros/maze/maze_5.78 b/uvim/runtime/macros/maze/maze_5.78
index dbe3d278b6..8d2e1805cd 100644
--- a/uvim/runtime/macros/maze/maze_5.78
+++ b/uvim/runtime/macros/maze/maze_5.78
@@ -5,7 +5,7 @@
| | . |_._| . ._._._| ._._. ._._| | | |_| . | |_. . ._|_| ._._. |_._|_| . | |
|_._|_._._._|_._._._|_|_._._._|_._|_._._._|_._._._|_._._._|_._._._._._._|_._|
-See Vim solve a maze!
+See MNV solve a maze!
type ":so maze_mac<RETURN>" to load the macros
diff --git a/uvim/runtime/macros/shellmenu.vim b/uvim/runtime/macros/shellmenu.mnv
index 4eb72a556a..4eb72a556a 100644
--- a/uvim/runtime/macros/shellmenu.vim
+++ b/uvim/runtime/macros/shellmenu.mnv
diff --git a/uvim/runtime/macros/swapmous.vim b/uvim/runtime/macros/swapmous.mnv
index 5884d83473..5884d83473 100644
--- a/uvim/runtime/macros/swapmous.vim
+++ b/uvim/runtime/macros/swapmous.mnv
diff --git a/uvim/runtime/macros/urm/README.txt b/uvim/runtime/macros/urm/README.txt
index 3995813689..eb4297f62a 100644
--- a/uvim/runtime/macros/urm/README.txt
+++ b/uvim/runtime/macros/urm/README.txt
@@ -1,20 +1,20 @@
-This is another proof that Vim is perfectly compatible with Vi.
+This is another proof that MNV is perfectly compatible with Vi.
The URM macro package was written by Rudolf Koenig ("Rudi")
(rudolf@koeniglich.de) for hpux-vi in August 1991.
Getting started:
type
-in your shell: vim urm<RETURN>
-in vim: :so urm.vim<RETURN>
-in vim: * (to load the registers and boot the URM-machine :-)
-in vim: g (for 'go') and watch the fun. Per default, 3 and 4
+in your shell: mnv urm<RETURN>
+in mnv: :so urm.mnv<RETURN>
+in mnv: * (to load the registers and boot the URM-machine :-)
+in mnv: g (for 'go') and watch the fun. Per default, 3 and 4
are multiplied. Watch the Program counter, it is
visible as a comma moving around.
This is a "standard URM" (Universal register machine) interpreter. The URM
concept is used in theoretical computer science to aid in theorem proving.
-Here it proves that vim is a general problem solver (if you bring enough
+Here it proves that mnv is a general problem solver (if you bring enough
patience).
The interpreter begins with register 1 (not 0), without macros and more-lines
diff --git a/uvim/runtime/macros/urm/urm.vim b/uvim/runtime/macros/urm/urm.mnv
index 3108180783..3108180783 100644
--- a/uvim/runtime/macros/urm/urm.vim
+++ b/uvim/runtime/macros/urm/urm.mnv
diff --git a/uvim/runtime/macros/less.sh b/uvim/runtime/macros/less.sh
index 32b5918918..ef8b34f96e 100755
--- a/uvim/runtime/macros/less.sh
+++ b/uvim/runtime/macros/less.sh
@@ -1,5 +1,5 @@
#!/bin/sh
# Shell script to start Vim with less.vim.
# Read stdin if no arguments were given and stdin was redirected.
if [ $# -eq 0 ] && [ -t 0 ]; then
@@ -10,7 +10,7 @@ fi
if [ -t 1 ]; then
[ $# -eq 0 ] && set -- "-"
[ "$*" != "-" ] && set -- -- "$@"
- exec vim --cmd 'let no_plugin_maps=1' -c 'runtime! macros/less.vim' --not-a-term "$@"
+ exec mnv --cmd 'let no_plugin_maps=1' -c 'runtime! macros/less.mnv' --not-a-term "$@"
else # Output is not a terminal.
exec cat -- "$@"
fi
@@ -1,5 +1,5 @@
#!/bin/sh
-# Shell script to start Vim with less.vim.
+# Shell script to start MNV with less.mnv.
# Read stdin if no arguments were given and stdin was redirected.
if [ $# -eq 0 ] && [ -t 0 ]; then